==> jc-1.4.0.tar.gz: javax/swing/plaf/OptionPaneUI.h <==
// public abstract class javax.swing.plaf.OptionPaneUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class a4393bf8a6ffd3dd javax_swing_plaf_OptionPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_OptionPaneUI_H_
#define _JC_javax_swing_plaf_OptionPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JOptionPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_OptionPaneUI$sub_refs	_jc_javax_swing_plaf_OptionPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs	_jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$refs	_jc_javax_swing_plaf_OptionPaneUI$refs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$nonrefs	_jc_javax_swing_plaf_OptionPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$object	_jc_javax_swing_plaf_OptionPaneUI$object;

typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vmethods	_jc_javax_swing_plaf_OptionPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vtable	_jc_javax_swing_plaf_OptionPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vtype	_jc_javax_swing_plaf_OptionPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_OptionPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *);

// Virtual methods
extern jboolean _jc_javax_swing_plaf_OptionPaneUI$method$containsCustomComponents$67cdee429b5cbdfd(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *);
extern void _jc_javax_swing_plaf_OptionPaneUI$method$selectInitialValue$dd45ad4bd4a07e55(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_OptionPaneUI$method_info$containsCustomComponents$67cdee429b5cbdfd;
extern _jc_method _jc_javax_swing_plaf_OptionPaneUI$method_info$selectInitialValue$dd45ad4bd4a07e55;

// Virtual methods structure
struct _jc_javax_swing_plaf_OptionPaneUI$vmethods {
	jboolean	(*containsCustomComponents$67cdee429b5cbdfd)(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *);
	void	(*selectInitialValue$dd45ad4bd4a07e55)(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *);
};

// Vtable
struct _jc_javax_swing_plaf_OptionPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_OptionPaneUI$vmethods	javax_swing_plaf_OptionPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_OptionPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_OptionPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_OptionPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_OptionPaneUI$refs {
    _jc_javax_swing_plaf_OptionPaneUI$sub_refs	javax_swing_plaf_OptionPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_OptionPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs	javax_swing_plaf_OptionPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_OptionPaneUI$object {
	_jc_javax_swing_plaf_OptionPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_OptionPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_OptionPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_OptionPaneUI$vtype _jc_javax_swing_plaf_OptionPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_OptionPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_OptionPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_OptionPaneUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/OptionPaneUI.h <==
// public abstract class javax.swing.plaf.OptionPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class a4393bf8a6ffd3dd javax_swing_plaf_OptionPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_OptionPaneUI_H_
#define _JC_javax_swing_plaf_OptionPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JOptionPane$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_OptionPaneUI$sub_refs	_jc_javax_swing_plaf_OptionPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs	_jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$refs	_jc_javax_swing_plaf_OptionPaneUI$refs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$nonrefs	_jc_javax_swing_plaf_OptionPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_OptionPaneUI$object	_jc_javax_swing_plaf_OptionPaneUI$object;

typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vmethods	_jc_javax_swing_plaf_OptionPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vtable	_jc_javax_swing_plaf_OptionPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_OptionPaneUI$vtype	_jc_javax_swing_plaf_OptionPaneUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_OptionPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_plaf_OptionPaneUI$method$containsCustomComponents$67cdee429b5cbdfd(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_OptionPaneUI$method$selectInitialValue$dd45ad4bd4a07e55(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_OptionPaneUI$method_info$containsCustomComponents$67cdee429b5cbdfd;
extern _jc_method _jc_javax_swing_plaf_OptionPaneUI$method_info$selectInitialValue$dd45ad4bd4a07e55;

// Virtual methods structure
struct _jc_javax_swing_plaf_OptionPaneUI$vmethods {
	jboolean	(*containsCustomComponents$67cdee429b5cbdfd)(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *) _JC_JCNI_ATTR;
	void	(*selectInitialValue$dd45ad4bd4a07e55)(_jc_env *, struct _jc_javax_swing_plaf_OptionPaneUI$object *, struct _jc_javax_swing_JOptionPane$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_OptionPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_OptionPaneUI$vmethods	javax_swing_plaf_OptionPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_OptionPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_OptionPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_OptionPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_OptionPaneUI$refs {
    _jc_javax_swing_plaf_OptionPaneUI$sub_refs	javax_swing_plaf_OptionPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_OptionPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_OptionPaneUI$sub_nonrefs	javax_swing_plaf_OptionPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_OptionPaneUI$object {
	_jc_javax_swing_plaf_OptionPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_OptionPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_OptionPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_OptionPaneUI$vtype _jc_javax_swing_plaf_OptionPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_OptionPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_OptionPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_OptionPaneUI_H_ */
